Streamlit Star Rating Component
===

This streamlit component adds a Dialog (Modal) with two buttons to Streamlit Apps. 

It implements the MUI Alert Dialog: https://mui.com/material-ui/react-dialog/

Installation
-----------

    $ pip install st-mui-dialog


Usage
------------

## Import the Component

    $ from st_mui_dialog import st_mui_dialog

    $ answer = st_mui_dialog(title="Confirmation", content="Please confirm that you want to save the changes", divider=True)

